@@ -1,6 +1,6 @@
 package Address::PostCode::UK;
 
-$Address::PostCode::UK::VERSION   = '0.16';
+$Address::PostCode::UK::VERSION   = '0.17';
 $Address::PostCode::UK::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Address::PostCode::UK - Interface to the UK PostCode.
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
@@ -25,7 +25,7 @@ use Address::PostCode::UK::Place::Council;
 use Address::PostCode::UK::Place::Constituency;
 
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 extends 'Address::PostCode::UserAgent';
 
 our $BASE_URL = 'http://uk-postcodes.com';
