@@ -1,6 +1,6 @@
 package Address::PostCode::UK::Place;
 
-$Address::PostCode::UK::Place::VERSION   = '0.16';
+$Address::PostCode::UK::Place::VERSION   = '0.17';
 $Address::PostCode::UK::Place::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Address::PostCode::UK::Place - Placeholder for 'place' for Address::PostCode::UK
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
@@ -17,7 +17,7 @@ use 5.006;
 use Data::Dumper;
 
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 
 has 'geo'          => (is => 'ro');
 has 'council'      => (is => 'ro');
